@@ -1,19 +1,19 @@
 <?php
 /**
- * Comments and Post Comments List Table classes.
+ * List Table API: WP_Comments_List_Table class
  *
  * @package WordPress
- * @subpackage List_Table
+ * @subpackage Administration
  * @since 3.1.0
  */
 
 /**
- * Comments List Table class.
+ * Core class used to implement displaying comments in a list table.
  *
- * @package WordPress
- * @subpackage List_Table
  * @since 3.1.0
  * @access private
+ *
+ * @see WP_List_Table
  */
 class WP_Comments_List_Table extends WP_List_Table {
 
@@ -42,8 +42,9 @@ class WP_Comments_List_Table extends WP_List_Table {
 
 		$post_id = isset( $_REQUEST['p'] ) ? absint( $_REQUEST['p'] ) : 0;
 
-		if ( get_option('show_avatars') )
-			add_filter( 'comment_author', 'floated_admin_avatar' );
+		if ( get_option( 'show_avatars' ) ) {
+			add_filter( 'comment_author', array( $this, 'floated_admin_avatar' ), 10, 2 );
+		}
 
 		parent::__construct( array(
 			'plural' => 'comments',
@@ -53,6 +54,12 @@ class WP_Comments_List_Table extends WP_List_Table {
 		) );
 	}
 
+	public function floated_admin_avatar( $name, $comment_ID ) {
+		$comment = get_comment( $comment_ID );
+		$avatar = get_avatar( $comment, 32, 'mystery' );
+		return "$avatar $name";
+	}
+
 	/**
 	 * @return bool
 	 */
@@ -176,10 +183,11 @@ class WP_Comments_List_Table extends WP_List_Table {
 	public function no_items() {
 		global $comment_status;
 
-		if ( 'moderated' == $comment_status )
+		if ( 'moderated' === $comment_status ) {
 			_e( 'No comments awaiting moderation.' );
-		else
+		} else {
 			_e( 'No comments found.' );
+		}
 	}
 
 	/**
@@ -196,22 +204,51 @@ class WP_Comments_List_Table extends WP_List_Table {
 		//, number_format_i18n($num_comments->moderated) ), "<span class='comment-count'>" . number_format_i18n($num_comments->moderated) . "</span>"),
 		//, number_format_i18n($num_comments->spam) ), "<span class='spam-comment-count'>" . number_format_i18n($num_comments->spam) . "</span>")
 		$stati = array(
-				'all' => _nx_noop('All', 'All', 'comments'), // singular not used
-				'moderated' => _n_noop('Pending <span class="count">(<span class="pending-count">%s</span>)</span>', 'Pending <span class="count">(<span class="pending-count">%s</span>)</span>'),
-				'approved' => _n_noop('Approved', 'Approved'), // singular not used
-				'spam' => _n_noop('Spam <span class="count">(<span class="spam-count">%s</span>)</span>', 'Spam <span class="count">(<span class="spam-count">%s</span>)</span>'),
-				'trash' => _n_noop('Trash <span class="count">(<span class="trash-count">%s</span>)</span>', 'Trash <span class="count">(<span class="trash-count">%s</span>)</span>')
-			);
+			/* translators: %s: all comments count */
+			'all' => _nx_noop(
+				'All <span class="count">(%s)</span>',
+				'All <span class="count">(%s)</span>',
+				'comments'
+			), // singular not used
+
+			/* translators: %s: pending comments count */
+			'moderated' => _nx_noop(
+				'Pending <span class="count">(%s)</span>',
+				'Pending <span class="count">(%s)</span>',
+				'comments'
+			),
+
+			/* translators: %s: approved comments count */
+			'approved' => _nx_noop(
+				'Approved <span class="count">(%s)</span>',
+				'Approved <span class="count">(%s)</span>',
+				'comments'
+			),
+
+			/* translators: %s: spam comments count */
+			'spam' => _nx_noop(
+				'Spam <span class="count">(%s)</span>',
+				'Spam <span class="count">(%s)</span>',
+				'comments'
+			),
+
+			/* translators: %s: trashed comments count */
+			'trash' => _nx_noop(
+				'Trash <span class="count">(%s)</span>',
+				'Trash <span class="count">(%s)</span>',
+				'comments'
+			)
+		);
 
 		if ( !EMPTY_TRASH_DAYS )
 			unset($stati['trash']);
 
-		$link = 'edit-comments.php';
+		$link = admin_url( 'edit-comments.php' );
 		if ( !empty($comment_type) && 'all' != $comment_type )
 			$link = add_query_arg( 'comment_type', $comment_type, $link );
 
 		foreach ( $stati as $status => $label ) {
-			$class = ( $status == $comment_status ) ? ' class="current"' : '';
+			$class = ( $status === $comment_status ) ? ' class="current"' : '';
 
 			if ( !isset( $num_comments->$status ) )
 				$num_comments->$status = 10;
@@ -223,9 +260,12 @@ class WP_Comments_List_Table extends WP_List_Table {
 			if ( !empty( $_REQUEST['s'] ) )
 				$link = add_query_arg( 's', esc_attr( wp_unslash( $_REQUEST['s'] ) ), $link );
 			*/
-			$status_links[$status] = "<a href='$link'$class>" . sprintf(
+			$status_links[ $status ] = "<a href='$link'$class>" . sprintf(
 				translate_nooped_plural( $label, $num_comments->$status ),
-				number_format_i18n( $num_comments->$status )
+				sprintf( '<span class="%s-count">%s</span>',
+					( 'moderated' === $status ) ? 'pending' : $status,
+					number_format_i18n( $num_comments->$status )
+				)
 			) . '</a>';
 		}
 
@@ -257,10 +297,11 @@ class WP_Comments_List_Table extends WP_List_Table {
 		if ( in_array( $comment_status, array( 'all', 'moderated', 'approved', 'trash' ) ) )
 			$actions['spam'] = _x( 'Mark as Spam', 'comment' );
 
-		if ( 'trash' == $comment_status )
+		if ( 'trash' === $comment_status ) {
 			$actions['untrash'] = __( 'Restore' );
-		elseif ( 'spam' == $comment_status )
+		} elseif ( 'spam' === $comment_status ) {
 			$actions['unspam'] = _x( 'Not Spam', 'comment' );
+		}
 
 		if ( in_array( $comment_status, array( 'trash', 'spam' ) ) || !EMPTY_TRASH_DAYS )
 			$actions['delete'] = __( 'Delete Permanently' );
@@ -282,7 +323,7 @@ class WP_Comments_List_Table extends WP_List_Table {
 ?>
 		<div class="alignleft actions">
 <?php
-		if ( 'top' == $which ) {
+		if ( 'top' === $which ) {
 ?>
 			<label class="screen-reader-text" for="filter-by-comment-type"><?php _e( 'Filter by comment type' ); ?></label>
 			<select id="filter-by-comment-type" name="comment_type">
@@ -314,9 +355,9 @@ class WP_Comments_List_Table extends WP_List_Table {
 			submit_button( __( 'Filter' ), 'button', 'filter_action', false, array( 'id' => 'post-query-submit' ) );
 		}
 
-		if ( ( 'spam' == $comment_status || 'trash' == $comment_status ) && current_user_can( 'moderate_comments' ) ) {
+		if ( ( 'spam' === $comment_status || 'trash' === $comment_status ) && current_user_can( 'moderate_comments' ) ) {
 			wp_nonce_field( 'bulk-destroy', '_destroy_nonce' );
-			$title = ( 'spam' == $comment_status ) ? esc_attr__( 'Empty Spam' ) : esc_attr__( 'Empty Trash' );
+			$title = ( 'spam' === $comment_status ) ? esc_attr__( 'Empty Spam' ) : esc_attr__( 'Empty Trash' );
 			submit_button( $title, 'apply', 'delete_all', false );
 		}
 		/**
@@ -362,6 +403,8 @@ class WP_Comments_List_Table extends WP_List_Table {
 			$columns['response'] = __( 'In Response To' );
 		}
 
+		$columns['date'] = _x( 'Submitted On', 'column name' );
+
 		return $columns;
 	}
 
@@ -372,7 +415,8 @@ class WP_Comments_List_Table extends WP_List_Table {
 	protected function get_sortable_columns() {
 		return array(
 			'author'   => 'comment_author',
-			'response' => 'comment_post_ID'
+			'response' => 'comment_post_ID',
+			'date'     => 'comment_date'
 		);
 	}
 
@@ -396,6 +440,8 @@ class WP_Comments_List_Table extends WP_List_Table {
 
 		$this->display_tablenav( 'top' );
 
+		$this->screen->render_screen_reader_content( 'heading_list' );
+
 ?>
 <table class="wp-list-table <?php echo implode( ' ', $this->get_table_classes() ); ?>">
 	<thead>
@@ -409,7 +455,10 @@ class WP_Comments_List_Table extends WP_List_Table {
 	</tbody>
 
 	<tbody id="the-extra-comment-list" data-wp-lists="list:comment" style="display: none;">
-		<?php $this->items = $this->extra_items; $this->display_rows(); ?>
+		<?php
+			$this->items = $this->extra_items;
+			$this->display_rows_or_placeholder();
+		?>
 	</tbody>
 
 	<tfoot>
@@ -425,29 +474,32 @@ class WP_Comments_List_Table extends WP_List_Table {
 	}
 
 	/**
+	 * @global WP_Post    $post
+	 * @global WP_Comment $comment
 	 *
-	 * @global WP_Post $post
-	 * @global object  $comment
-	 *
-	 * @param object $a_comment
+	 * @param WP_Comment $item
 	 */
-	public function single_row( $a_comment ) {
+	public function single_row( $item ) {
 		global $post, $comment;
 
-		$comment = $a_comment;
-		$the_comment_class = wp_get_comment_status( $comment->comment_ID );
+		$comment = $item;
+
+		$the_comment_class = wp_get_comment_status( $comment );
 		if ( ! $the_comment_class ) {
 			$the_comment_class = '';
 		}
-		$the_comment_class = join( ' ', get_comment_class( $the_comment_class, $comment->comment_ID, $comment->comment_post_ID ) );
-
-		$post = get_post( $comment->comment_post_ID );
+		$the_comment_class = join( ' ', get_comment_class( $the_comment_class, $comment, $comment->comment_post_ID ) );
 
+		if ( $comment->comment_post_ID > 0 ) {
+			$post = get_post( $comment->comment_post_ID );
+		}
 		$this->user_can = current_user_can( 'edit_comment', $comment->comment_ID );
 
 		echo "<tr id='comment-$comment->comment_ID' class='$the_comment_class'>";
 		$this->single_row_columns( $comment );
 		echo "</tr>\n";
+
+		unset( $post, $comment );
 	}
 
  	/**
@@ -456,6 +508,8 @@ class WP_Comments_List_Table extends WP_List_Table {
  	 * @since 4.3.0
  	 * @access protected
  	 *
+ 	 * @global string $comment_status Status for the current listed comments.
+ 	 *
  	 * @param object $comment     Comment being acted upon.
  	 * @param string $column_name Current column name.
  	 * @param string $primary     Primary column name.
@@ -472,7 +526,7 @@ class WP_Comments_List_Table extends WP_List_Table {
  			return;
 		}
 
-		$the_comment_status = wp_get_comment_status( $comment->comment_ID );
+		$the_comment_status = wp_get_comment_status( $comment );
 
 		$out = '';
 
@@ -501,9 +555,9 @@ class WP_Comments_List_Table extends WP_List_Table {
 
 		// Not looking at all comments.
 		if ( $comment_status && 'all' != $comment_status ) {
-			if ( 'approved' == $the_comment_status ) {
+			if ( 'approved' === $the_comment_status ) {
 				$actions['unapprove'] = "<a href='$unapprove_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID:e7e7d3:action=dim-comment&amp;new=unapproved' class='vim-u vim-destructive' title='" . esc_attr__( 'Unapprove this comment' ) . "'>" . __( 'Unapprove' ) . '</a>';
-			} elseif ( 'unapproved' == $the_comment_status ) {
+			} elseif ( 'unapproved' === $the_comment_status ) {
 				$actions['approve'] = "<a href='$approve_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID:e7e7d3:action=dim-comment&amp;new=approved' class='vim-a vim-destructive' title='" . esc_attr__( 'Approve this comment' ) . "'>" . __( 'Approve' ) . '</a>';
 			}
 		} else {
@@ -511,23 +565,23 @@ class WP_Comments_List_Table extends WP_List_Table {
 			$actions['unapprove'] = "<a href='$unapprove_url' data-wp-lists='dim:the-comment-list:comment-$comment->comment_ID:unapproved:e7e7d3:e7e7d3:new=unapproved' class='vim-u' title='" . esc_attr__( 'Unapprove this comment' ) . "'>" . __( 'Unapprove' ) . '</a>';
 		}
 
-		if ( 'spam' != $the_comment_status ) {
+		if ( 'spam' !== $the_comment_status ) {
 			$actions['spam'] = "<a href='$spam_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID::spam=1' class='vim-s vim-destructive' title='" . esc_attr__( 'Mark this comment as spam' ) . "'>" . /* translators: mark as spam link */ _x( 'Spam', 'verb' ) . '</a>';
-		} elseif ( 'spam' == $the_comment_status ) {
+		} elseif ( 'spam' === $the_comment_status ) {
 			$actions['unspam'] = "<a href='$unspam_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID:66cc66:unspam=1' class='vim-z vim-destructive'>" . _x( 'Not Spam', 'comment' ) . '</a>';
 		}
 
-		if ( 'trash' == $the_comment_status ) {
+		if ( 'trash' === $the_comment_status ) {
 			$actions['untrash'] = "<a href='$untrash_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID:66cc66:untrash=1' class='vim-z vim-destructive'>" . __( 'Restore' ) . '</a>';
 		}
 
-		if ( 'spam' == $the_comment_status || 'trash' == $the_comment_status || !EMPTY_TRASH_DAYS ) {
+		if ( 'spam' === $the_comment_status || 'trash' === $the_comment_status || !EMPTY_TRASH_DAYS ) {
 			$actions['delete'] = "<a href='$delete_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID::delete=1' class='delete vim-d vim-destructive'>" . __( 'Delete Permanently' ) . '</a>';
 		} else {
 			$actions['trash'] = "<a href='$trash_url' data-wp-lists='delete:the-comment-list:comment-$comment->comment_ID::trash=1' class='delete vim-d vim-destructive' title='" . esc_attr__( 'Move this comment to the trash' ) . "'>" . _x( 'Trash', 'verb' ) . '</a>';
 		}
 
-		if ( 'spam' != $the_comment_status && 'trash' != $the_comment_status ) {
+		if ( 'spam' !== $the_comment_status && 'trash' !== $the_comment_status ) {
 			$actions['edit'] = "<a href='comment.php?action=editcomment&amp;c={$comment->comment_ID}' title='" . esc_attr__( 'Edit comment' ) . "'>". __( 'Edit' ) . '</a>';
 
 			$format = '<a data-comment-id="%d" data-post-id="%d" data-action="%s" class="%s" title="%s" href="#">%s</a>';
@@ -544,12 +598,12 @@ class WP_Comments_List_Table extends WP_List_Table {
 		$out .= '<div class="row-actions">';
 		foreach ( $actions as $action => $link ) {
 			++$i;
-			( ( ( 'approve' == $action || 'unapprove' == $action ) && 2 === $i ) || 1 === $i ) ? $sep = '' : $sep = ' | ';
+			( ( ( 'approve' === $action || 'unapprove' === $action ) && 2 === $i ) || 1 === $i ) ? $sep = '' : $sep = ' | ';
 
 			// Reply and quickedit need a hide-if-no-js span when not added with ajax
-			if ( ( 'reply' == $action || 'quickedit' == $action ) && ! defined('DOING_AJAX') )
+			if ( ( 'reply' === $action || 'quickedit' === $action ) && ! defined('DOING_AJAX') )
 				$action .= ' hide-if-no-js';
-			elseif ( ( $action == 'untrash' && $the_comment_status == 'trash' ) || ( $action == 'unspam' && $the_comment_status == 'spam' ) ) {
+			elseif ( ( $action === 'untrash' && $the_comment_status === 'trash' ) || ( $action === 'unspam' && $the_comment_status === 'spam' ) ) {
 				if ( '1' == get_comment_meta( $comment->comment_ID, '_wp_trash_meta_status', true ) )
 					$action .= ' approve';
 				else
@@ -581,29 +635,24 @@ class WP_Comments_List_Table extends WP_List_Table {
 	 * @param object $comment
 	 */
 	public function column_comment( $comment ) {
-		$comment_url = esc_url( get_comment_link( $comment->comment_ID ) );
-
 		echo '<div class="comment-author">';
 			$this->column_author( $comment );
 		echo '</div>';
 
-		echo '<div class="submitted-on">';
-		/* translators: 2: comment date, 3: comment time */
-		printf( __( 'Submitted on <a href="%1$s">%2$s at %3$s</a>' ), $comment_url,
-			/* translators: comment date format. See http://php.net/date */
-			get_comment_date( __( 'Y/m/d' ) ),
-			get_comment_date( get_option( 'time_format' ) )
-		);
-
 		if ( $comment->comment_parent ) {
 			$parent = get_comment( $comment->comment_parent );
-			$parent_link = esc_url( get_comment_link( $comment->comment_parent ) );
-			$name = get_comment_author( $parent->comment_ID );
-			printf( ' | '.__( 'In reply to <a href="%1$s">%2$s</a>.' ), $parent_link, $name );
+			if ( $parent ) {
+				$parent_link = esc_url( get_comment_link( $parent ) );
+				$name = get_comment_author( $parent );
+				printf(
+					/* translators: %s: comment link */
+					__( 'In reply to %s.' ),
+					'<a href="' . $parent_link . '">' . $name . '</a>'
+				);
+			}
 		}
 
-		echo '</div>';
-		comment_text();
+		comment_text( $comment );
 		if ( $this->user_can ) { ?>
 		<div id="inline-<?php echo $comment->comment_ID; ?>" class="hidden">
 		<textarea class="comment" rows="1" cols="1"><?php
@@ -628,40 +677,53 @@ class WP_Comments_List_Table extends WP_List_Table {
 	public function column_author( $comment ) {
 		global $comment_status;
 
-		$author_url = get_comment_author_url();
-		if ( 'http://' == $author_url )
-			$author_url = '';
-		$author_url_display = preg_replace( '|http://(www\.)?|i', '', $author_url );
-		if ( strlen( $author_url_display ) > 50 )
-			$author_url_display = substr( $author_url_display, 0, 49 ) . '&hellip;';
+		$author_url = get_comment_author_url( $comment );
 
-		echo "<strong>"; comment_author(); echo '</strong><br />';
-		if ( !empty( $author_url ) )
-			echo "<a title='$author_url' href='$author_url'>$author_url_display</a><br />";
+		$author_url_display = untrailingslashit( preg_replace( '|^http(s)?://(www\.)?|i', '', $author_url ) );
+		if ( strlen( $author_url_display ) > 50 ) {
+			$author_url_display = wp_html_excerpt( $author_url_display, 49, '&hellip;' );
+		}
+
+		echo "<strong>"; comment_author( $comment ); echo '</strong><br />';
+		if ( ! empty( $author_url_display ) ) {
+			printf( '<a href="%s">%s</a><br />', esc_url( $author_url ), esc_html( $author_url_display ) );
+		}
 
 		if ( $this->user_can ) {
-			if ( !empty( $comment->comment_author_email ) ) {
-				comment_author_email_link();
-				echo '<br />';
+			if ( ! empty( $comment->comment_author_email ) ) {
+				/* This filter is documented in wp-includes/comment-template.php */
+				$email = apply_filters( 'comment_email', $comment->comment_author_email, $comment );
+
+				if ( ! empty( $email ) && '@' !== $email ) {
+					printf( '<a href="%1$s">%2$s</a><br />', esc_url( 'mailto:' . $email ), esc_html( $email ) );
+				}
 			}
 
-			$author_ip = get_comment_author_IP();
+			$author_ip = get_comment_author_IP( $comment );
 			if ( $author_ip ) {
-				$author_ip_url = add_query_arg( array( 's' => $author_ip, 'mode' => 'detail' ), 'edit-comments.php' );
-				if ( 'spam' == $comment_status ) {
+				$author_ip_url = add_query_arg( array( 's' => $author_ip, 'mode' => 'detail' ), admin_url( 'edit-comments.php' ) );
+				if ( 'spam' === $comment_status ) {
 					$author_ip_url = add_query_arg( 'comment_status', 'spam', $author_ip_url );
 				}
-				printf( '<a href="%s">%s</a>', esc_url( $author_ip_url ), $author_ip );
+				printf( '<a href="%1$s">%2$s</a>', esc_url( $author_ip_url ), esc_html( $author_ip ) );
 			}
 		}
 	}
 
 	/**
-	 *
-	 * @return string
+	 * @access public
 	 */
-	public function column_date() {
-		return get_comment_date( __( 'Y/m/d \a\t g:i a' ) );
+	public function column_date( $comment ) {
+		echo '<div class="submitted-on">';
+		echo '<a href="' . esc_url( get_comment_link( $comment ) ) . '">';
+		/* translators: 1: comment date, 2: comment time */
+		printf( __( '%1$s at %2$s' ),
+			/* translators: comment date format. See http://php.net/date */
+			get_comment_date( __( 'Y/m/d' ), $comment ),
+			get_comment_date( get_option( 'time_format' ), $comment )
+		);
+		echo '</a>';
+		echo '</div>';
 	}
 
 	/**
@@ -689,13 +751,13 @@ class WP_Comments_List_Table extends WP_List_Table {
 		}
 
 		echo '<div class="response-links">';
-		if ( 'attachment' == $post->post_type && ( $thumb = wp_get_attachment_image( $post->ID, array( 80, 60 ), true ) ) ) {
+		if ( 'attachment' === $post->post_type && ( $thumb = wp_get_attachment_image( $post->ID, array( 80, 60 ), true ) ) ) {
 			echo $thumb;
 		}
 		echo $post_link;
 		$post_type_object = get_post_type_object( $post->post_type );
 		echo "<a href='" . get_permalink( $post->ID ) . "' class='comments-view-item-link'>" . $post_type_object->labels->view_item . '</a>';
-		echo '<span class="post-com-count-wrapper">';
+		echo '<span class="post-com-count-wrapper post-com-count-', $post->ID, '">';
 		$this->comments_bubble( $post->ID, $pending_comments );
 		echo '</span> ';
 		echo '</div>';
@@ -718,74 +780,3 @@ class WP_Comments_List_Table extends WP_List_Table {
 		do_action( 'manage_comments_custom_column', $column_name, $comment->comment_ID );
 	}
 }
-
-/**
- * Post Comments List Table class.
- *
- * @package WordPress
- * @subpackage List_Table
- * @since 3.1.0
- * @access private
- *
- * @see WP_Comments_Table
- */
-class WP_Post_Comments_List_Table extends WP_Comments_List_Table {
-
-	/**
-	 *
-	 * @return array
-	 */
-	protected function get_column_info() {
-		return array(
-			array(
-				'author'   => __( 'Author' ),
-				'comment'  => _x( 'Comment', 'column name' ),
-			),
-			array(),
-			array(),
-			'comment',
-		);
-	}
-
-	/**
-	 *
-	 * @return array
-	 */
-	protected function get_table_classes() {
-		$classes = parent::get_table_classes();
-		$classes[] = 'wp-list-table';
-		$classes[] = 'comments-box';
-		return $classes;
-	}
-
-	/**
-	 *
-	 * @param bool $output_empty
-	 */
-	public function display( $output_empty = false ) {
-		$singular = $this->_args['singular'];
-
-		wp_nonce_field( "fetch-list-" . get_class( $this ), '_ajax_fetch_list_nonce' );
-?>
-<table class="<?php echo implode( ' ', $this->get_table_classes() ); ?>" style="display:none;">
-	<tbody id="the-comment-list"<?php
-		if ( $singular ) {
-			echo " data-wp-lists='list:$singular'";
-		} ?>>
-		<?php if ( ! $output_empty ) {
-			$this->display_rows_or_placeholder();
-		} ?>
-	</tbody>
-</table>
-<?php
-	}
-
-	/**
-	 *
-	 * @param bool $comment_status
-	 * @return int
-	 */
-	public function get_per_page( $comment_status = false ) {
-		return 10;
-	}
-}
