@@ -1,335 +1,17 @@
 <?php
-
 /**
- * Create HTML list of nav menu input items.
+ * Core Navigation Menu API
  *
  * @package WordPress
+ * @subpackage Nav_Menus
  * @since 3.0.0
- * @uses Walker_Nav_Menu
  */
-class Walker_Nav_Menu_Edit extends Walker_Nav_Menu {
-	/**
-	 * Starts the list before the elements are added.
-	 *
-	 * @see Walker_Nav_Menu::start_lvl()
-	 *
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference.
-	 * @param int    $depth  Depth of menu item. Used for padding.
-	 * @param array  $args   Not used.
-	 */
-	public function start_lvl( &$output, $depth = 0, $args = array() ) {}
 
-	/**
-	 * Ends the list of after the elements are added.
-	 *
-	 * @see Walker_Nav_Menu::end_lvl()
-	 *
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference.
-	 * @param int    $depth  Depth of menu item. Used for padding.
-	 * @param array  $args   Not used.
-	 */
-	public function end_lvl( &$output, $depth = 0, $args = array() ) {}
+/** Walker_Nav_Menu_Edit class */
+require_once( ABSPATH . 'wp-admin/includes/class-walker-nav-menu-edit.php' );
 
-	/**
-	 * Start the element output.
-	 *
-	 * @see Walker_Nav_Menu::start_el()
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference. Used to append additional content.
-	 * @param object $item   Menu item data object.
-	 * @param int    $depth  Depth of menu item. Used for padding.
-	 * @param array  $args   Not used.
-	 * @param int    $id     Not used.
-	 */
-	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
-		global $_wp_nav_menu_max_depth;
-		$_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;
-
-		ob_start();
-		$item_id = esc_attr( $item->ID );
-		$removed_args = array(
-			'action',
-			'customlink-tab',
-			'edit-menu-item',
-			'menu-item',
-			'page-tab',
-			'_wpnonce',
-		);
-
-		$original_title = '';
-		if ( 'taxonomy' == $item->type ) {
-			$original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
-			if ( is_wp_error( $original_title ) )
-				$original_title = false;
-		} elseif ( 'post_type' == $item->type ) {
-			$original_object = get_post( $item->object_id );
-			$original_title = get_the_title( $original_object->ID );
-		}
-
-		$classes = array(
-			'menu-item menu-item-depth-' . $depth,
-			'menu-item-' . esc_attr( $item->object ),
-			'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
-		);
-
-		$title = $item->title;
-
-		if ( ! empty( $item->_invalid ) ) {
-			$classes[] = 'menu-item-invalid';
-			/* translators: %s: title of menu item which is invalid */
-			$title = sprintf( __( '%s (Invalid)' ), $item->title );
-		} elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
-			$classes[] = 'pending';
-			/* translators: %s: title of menu item in draft status */
-			$title = sprintf( __('%s (Pending)'), $item->title );
-		}
-
-		$title = ( ! isset( $item->label ) || '' == $item->label ) ? $title : $item->label;
-
-		$submenu_text = '';
-		if ( 0 == $depth )
-			$submenu_text = 'style="display: none;"';
-
-		?>
-		<li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode(' ', $classes ); ?>">
-			<dl class="menu-item-bar">
-				<dt class="menu-item-handle">
-					<span class="item-title"><span class="menu-item-title"><?php echo esc_html( $title ); ?></span> <span class="is-submenu" <?php echo $submenu_text; ?>><?php _e( 'sub item' ); ?></span></span>
-					<span class="item-controls">
-						<span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
-						<span class="item-order hide-if-js">
-							<a href="<?php
-								echo wp_nonce_url(
-									add_query_arg(
-										array(
-											'action' => 'move-up-menu-item',
-											'menu-item' => $item_id,
-										),
-										remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
-									),
-									'move-menu_item'
-								);
-							?>" class="item-move-up"><abbr title="<?php esc_attr_e('Move up'); ?>">&#8593;</abbr></a>
-							|
-							<a href="<?php
-								echo wp_nonce_url(
-									add_query_arg(
-										array(
-											'action' => 'move-down-menu-item',
-											'menu-item' => $item_id,
-										),
-										remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
-									),
-									'move-menu_item'
-								);
-							?>" class="item-move-down"><abbr title="<?php esc_attr_e('Move down'); ?>">&#8595;</abbr></a>
-						</span>
-						<a class="item-edit" id="edit-<?php echo $item_id; ?>" title="<?php esc_attr_e('Edit Menu Item'); ?>" href="<?php
-							echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
-						?>"><?php _e( 'Edit Menu Item' ); ?></a>
-					</span>
-				</dt>
-			</dl>
-
-			<div class="menu-item-settings" id="menu-item-settings-<?php echo $item_id; ?>">
-				<?php if( 'custom' == $item->type ) : ?>
-					<p class="field-url description description-wide">
-						<label for="edit-menu-item-url-<?php echo $item_id; ?>">
-							<?php _e( 'URL' ); ?><br />
-							<input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
-						</label>
-					</p>
-				<?php endif; ?>
-				<p class="description description-thin">
-					<label for="edit-menu-item-title-<?php echo $item_id; ?>">
-						<?php _e( 'Navigation Label' ); ?><br />
-						<input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
-					</label>
-				</p>
-				<p class="description description-thin">
-					<label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
-						<?php _e( 'Title Attribute' ); ?><br />
-						<input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
-					</label>
-				</p>
-				<p class="field-link-target description">
-					<label for="edit-menu-item-target-<?php echo $item_id; ?>">
-						<input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
-						<?php _e( 'Open link in a new window/tab' ); ?>
-					</label>
-				</p>
-				<p class="field-css-classes description description-thin">
-					<label for="edit-menu-item-classes-<?php echo $item_id; ?>">
-						<?php _e( 'CSS Classes (optional)' ); ?><br />
-						<input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
-					</label>
-				</p>
-				<p class="field-xfn description description-thin">
-					<label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
-						<?php _e( 'Link Relationship (XFN)' ); ?><br />
-						<input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
-					</label>
-				</p>
-				<p class="field-description description description-wide">
-					<label for="edit-menu-item-description-<?php echo $item_id; ?>">
-						<?php _e( 'Description' ); ?><br />
-						<textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
-						<span class="description"><?php _e('The description will be displayed in the menu if the current theme supports it.'); ?></span>
-					</label>
-				</p>
-
-				<p class="field-move hide-if-no-js description description-wide">
-					<label>
-						<span><?php _e( 'Move' ); ?></span>
-						<a href="#" class="menus-move-up"><?php _e( 'Up one' ); ?></a>
-						<a href="#" class="menus-move-down"><?php _e( 'Down one' ); ?></a>
-						<a href="#" class="menus-move-left"></a>
-						<a href="#" class="menus-move-right"></a>
-						<a href="#" class="menus-move-top"><?php _e( 'To the top' ); ?></a>
-					</label>
-				</p>
-
-				<div class="menu-item-actions description-wide submitbox">
-					<?php if( 'custom' != $item->type && $original_title !== false ) : ?>
-						<p class="link-to-original">
-							<?php printf( __('Original: %s'), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
-						</p>
-					<?php endif; ?>
-					<a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
-					echo wp_nonce_url(
-						add_query_arg(
-							array(
-								'action' => 'delete-menu-item',
-								'menu-item' => $item_id,
-							),
-							admin_url( 'nav-menus.php' )
-						),
-						'delete-menu_item_' . $item_id
-					); ?>"><?php _e( 'Remove' ); ?></a> <span class="meta-sep hide-if-no-js"> | </span> <a class="item-cancel submitcancel hide-if-no-js" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array( 'edit-menu-item' => $item_id, 'cancel' => time() ), admin_url( 'nav-menus.php' ) ) );
-						?>#menu-item-settings-<?php echo $item_id; ?>"><?php _e('Cancel'); ?></a>
-				</div>
-
-				<input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>" />
-				<input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
-				<input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
-				<input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
-				<input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
-				<input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
-			</div><!-- .menu-item-settings-->
-			<ul class="menu-item-transport"></ul>
-		<?php
-		$output .= ob_get_clean();
-	}
-
-} // Walker_Nav_Menu_Edit
-
-/**
- * Create HTML list of nav menu input items.
- *
- * @since 3.0.0
- * @uses Walker_Nav_Menu
- */
-class Walker_Nav_Menu_Checklist extends Walker_Nav_Menu {
-	public function __construct( $fields = false ) {
-		if ( $fields ) {
-			$this->db_fields = $fields;
-		}
-	}
-
-	/**
-	 * Starts the list before the elements are added.
-	 *
-	 * @see Walker_Nav_Menu::start_lvl()
-	 *
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference. Used to append additional content.
-	 * @param int    $depth  Depth of page. Used for padding.
-	 * @param array  $args   Not used.
-	 */
-	public function start_lvl( &$output, $depth = 0, $args = array() ) {
-		$indent = str_repeat( "\t", $depth );
-		$output .= "\n$indent<ul class='children'>\n";
-	}
-
-	/**
-	 * Ends the list of after the elements are added.
-	 *
-	 * @see Walker_Nav_Menu::end_lvl()
-	 *
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference. Used to append additional content.
-	 * @param int    $depth  Depth of page. Used for padding.
-	 * @param array  $args   Not used.
-	 */
-	public function end_lvl( &$output, $depth = 0, $args = array() ) {
-		$indent = str_repeat( "\t", $depth );
-		$output .= "\n$indent</ul>";
-	}
-
-	/**
-	 * Start the element output.
-	 *
-	 * @see Walker_Nav_Menu::start_el()
-	 *
-	 * @since 3.0.0
-	 *
-	 * @param string $output Passed by reference. Used to append additional content.
-	 * @param object $item   Menu item data object.
-	 * @param int    $depth  Depth of menu item. Used for padding.
-	 * @param array  $args   Not used.
-	 * @param int    $id     Not used.
-	 */
-	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
-		global $_nav_menu_placeholder;
-
-		$_nav_menu_placeholder = ( 0 > $_nav_menu_placeholder ) ? intval($_nav_menu_placeholder) - 1 : -1;
-		$possible_object_id = isset( $item->post_type ) && 'nav_menu_item' == $item->post_type ? $item->object_id : $_nav_menu_placeholder;
-		$possible_db_id = ( ! empty( $item->ID ) ) && ( 0 < $possible_object_id ) ? (int) $item->ID : 0;
-
-		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
-
-		$output .= $indent . '<li>';
-		$output .= '<label class="menu-item-title">';
-		$output .= '<input type="checkbox" class="menu-item-checkbox';
-
-		if ( ! empty( $item->front_or_home ) )
-			$output .= ' add-to-top';
-
-		$output .= '" name="menu-item[' . $possible_object_id . '][menu-item-object-id]" value="'. esc_attr( $item->object_id ) .'" /> ';
-
-		if ( ! empty( $item->label ) ) {
-			$title = $item->label;
-		} elseif ( isset( $item->post_type ) ) {
-			/** This filter is documented in wp-includes/post-template.php */
-			$title = apply_filters( 'the_title', $item->post_title, $item->ID );
-			if ( ! empty( $item->front_or_home ) && _x( 'Home', 'nav menu home label' ) !== $title )
-				$title = sprintf( _x( 'Home: %s', 'nav menu front page title' ), $title );
-		}
-
-		$output .= isset( $title ) ? esc_html( $title ) : esc_html( $item->title );
- 		$output .= '</label>';
-
-		// Menu item hidden fields
-		$output .= '<input type="hidden" class="menu-item-db-id" name="menu-item[' . $possible_object_id . '][menu-item-db-id]" value="' . $possible_db_id . '" />';
-		$output .= '<input type="hidden" class="menu-item-object" name="menu-item[' . $possible_object_id . '][menu-item-object]" value="'. esc_attr( $item->object ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-parent-id" name="menu-item[' . $possible_object_id . '][menu-item-parent-id]" value="'. esc_attr( $item->menu_item_parent ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-type" name="menu-item[' . $possible_object_id . '][menu-item-type]" value="'. esc_attr( $item->type ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-title" name="menu-item[' . $possible_object_id . '][menu-item-title]" value="'. esc_attr( $item->title ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-url" name="menu-item[' . $possible_object_id . '][menu-item-url]" value="'. esc_attr( $item->url ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-target" name="menu-item[' . $possible_object_id . '][menu-item-target]" value="'. esc_attr( $item->target ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-attr_title" name="menu-item[' . $possible_object_id . '][menu-item-attr_title]" value="'. esc_attr( $item->attr_title ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-classes" name="menu-item[' . $possible_object_id . '][menu-item-classes]" value="'. esc_attr( implode( ' ', $item->classes ) ) .'" />';
-		$output .= '<input type="hidden" class="menu-item-xfn" name="menu-item[' . $possible_object_id . '][menu-item-xfn]" value="'. esc_attr( $item->xfn ) .'" />';
-	}
-
-} // Walker_Nav_Menu_Checklist
+/** Walker_Nav_Menu_Checklist class */
+require_once( ABSPATH . 'wp-admin/includes/class-walker-nav-menu-checklist.php' );
 
 /**
  * Prints the appropriate response to a menu quick search.
@@ -418,7 +100,7 @@ function _wp_ajax_menu_quick_search( $request = array() ) {
 			));
 			if ( empty( $terms ) || is_wp_error( $terms ) )
 				return;
-			foreach( (array) $terms as $term ) {
+			foreach ( (array) $terms as $term ) {
 				if ( 'markup' == $response_format ) {
 					echo walk_nav_menu_tree( array_map('wp_setup_nav_menu_item', array( $term ) ), 0, (object) $args );
 				} elseif ( 'json' == $response_format ) {
@@ -444,25 +126,27 @@ function _wp_ajax_menu_quick_search( $request = array() ) {
 function wp_nav_menu_setup() {
 	// Register meta boxes
 	wp_nav_menu_post_type_meta_boxes();
-	add_meta_box( 'add-custom-links', __( 'Links' ), 'wp_nav_menu_item_link_meta_box', 'nav-menus', 'side', 'default' );
+	add_meta_box( 'add-custom-links', __( 'Custom Links' ), 'wp_nav_menu_item_link_meta_box', 'nav-menus', 'side', 'default' );
 	wp_nav_menu_taxonomy_meta_boxes();
 
 	// Register advanced menu items (columns)
 	add_filter( 'manage_nav-menus_columns', 'wp_nav_menu_manage_columns' );
 
 	// If first time editing, disable advanced items by default.
-	if( false === get_user_option( 'managenav-menuscolumnshidden' ) ) {
+	if ( false === get_user_option( 'managenav-menuscolumnshidden' ) ) {
 		$user = wp_get_current_user();
 		update_user_option($user->ID, 'managenav-menuscolumnshidden',
-			array( 0 => 'link-target', 1 => 'css-classes', 2 => 'xfn', 3 => 'description', ),
+			array( 0 => 'link-target', 1 => 'css-classes', 2 => 'xfn', 3 => 'description', 4 => 'title-attribute', ),
 			true);
 	}
 }
 
 /**
- * Limit the amount of meta boxes to just links, pages and cats for first time users.
+ * Limit the amount of meta boxes to pages, posts, links, and categories for first time users.
  *
  * @since 3.0.0
+ *
+ * @global array $wp_meta_boxes
  **/
 function wp_initial_nav_menu_meta_boxes() {
 	global $wp_meta_boxes;
@@ -470,7 +154,7 @@ function wp_initial_nav_menu_meta_boxes() {
 	if ( get_user_option( 'metaboxhidden_nav-menus' ) !== false || ! is_array($wp_meta_boxes) )
 		return;
 
-	$initial_meta_boxes = array( 'nav-menu-theme-locations', 'add-page', 'add-custom-links', 'add-category' );
+	$initial_meta_boxes = array( 'add-post-type-page', 'add-post-type-post', 'add-custom-links', 'add-category' );
 	$hidden_meta_boxes = array();
 
 	foreach ( array_keys($wp_meta_boxes['nav-menus']) as $context ) {
@@ -518,7 +202,7 @@ function wp_nav_menu_post_type_meta_boxes() {
 			$id = $post_type->name;
 			// Give pages a higher priority.
 			$priority = ( 'page' == $post_type->name ? 'core' : 'default' );
-			add_meta_box( "add-{$id}", $post_type->labels->name, 'wp_nav_menu_item_post_type_meta_box', 'nav-menus', 'side', $priority, $post_type );
+			add_meta_box( "add-post-type-{$id}", $post_type->labels->name, 'wp_nav_menu_item_post_type_meta_box', 'nav-menus', 'side', $priority, $post_type );
 		}
 	}
 }
@@ -549,7 +233,7 @@ function wp_nav_menu_taxonomy_meta_boxes() {
  *
  * @since 3.6.0
  *
- * @uses global $one_theme_location_no_menus to determine if no menus exist
+ * @global bool $one_theme_location_no_menus to determine if no menus exist
  *
  * @param int|string $nav_menu_selected_id (id, name or slug) of the currently-selected menu
  * @return string Disabled attribute if at least one menu exists, false if not
@@ -567,6 +251,9 @@ function wp_nav_menu_disabled_check( $nav_menu_selected_id ) {
  * Displays a metabox for the custom links menu item.
  *
  * @since 3.0.0
+ *
+ * @global int        $_nav_menu_placeholder
+ * @global int|string $nav_menu_selected_id
  */
 function wp_nav_menu_item_link_meta_box() {
 	global $_nav_menu_placeholder, $nav_menu_selected_id;
@@ -606,6 +293,9 @@ function wp_nav_menu_item_link_meta_box() {
  *
  * @since 3.0.0
  *
+ * @global int        $_nav_menu_placeholder
+ * @global int|string $nav_menu_selected_id
+ *
  * @param string $object Not used.
  * @param string $post_type The post type object.
  */
@@ -712,6 +402,21 @@ function wp_nav_menu_item_post_type_meta_box( $object, $post_type ) {
 				$recent_args = array_merge( $args, array( 'orderby' => 'post_date', 'order' => 'DESC', 'posts_per_page' => 15 ) );
 				$most_recent = $get_posts->query( $recent_args );
 				$args['walker'] = $walker;
+
+				/**
+				 * Filter the posts displayed in the 'Most Recent' tab of the current
+				 * post type's menu items meta box.
+				 *
+				 * The dynamic portion of the hook name, `$post_type_name`, refers to the post type name.
+				 *
+				 * @since 4.3.0
+				 *
+				 * @param array  $most_recent An array of post objects being listed.
+				 * @param array  $args        An array of WP_Query arguments.
+				 * @param object $post_type   The current post type object for this menu item meta box.
+				 */
+				$most_recent = apply_filters( "nav_menu_items_{$post_type_name}_recent", $most_recent, $args, $post_type );
+
 				echo walk_nav_menu_tree( array_map('wp_setup_nav_menu_item', $most_recent), 0, (object) $args );
 				?>
 			</ul>
@@ -788,6 +493,23 @@ function wp_nav_menu_item_post_type_meta_box( $object, $post_type ) {
 					}
 				}
 
+				$post_type = get_post_type_object( $post_type_name );
+				$archive_link = get_post_type_archive_link( $post_type_name );
+				if ( $post_type->has_archive ) {
+					$_nav_menu_placeholder = ( 0 > $_nav_menu_placeholder ) ? intval($_nav_menu_placeholder) - 1 : -1;
+					array_unshift( $posts, (object) array(
+						'ID' => 0,
+						'object_id' => $_nav_menu_placeholder,
+						'object'     => $post_type_name,
+						'post_content' => '',
+						'post_excerpt' => '',
+						'post_title' => $post_type->labels->archives,
+						'post_type' => 'nav_menu_item',
+						'type' => 'post_type_archive',
+						'url' => get_post_type_archive_link( $post_type_name ),
+					) );
+				}
+
 				/**
 				 * Filter the posts displayed in the 'View All' tab of the current
 				 * post type's menu items meta box.
@@ -849,6 +571,8 @@ function wp_nav_menu_item_post_type_meta_box( $object, $post_type ) {
  *
  * @since 3.0.0
  *
+ * @global int|string $nav_menu_selected_id
+ *
  * @param string $object Not used.
  * @param string $taxonomy The taxonomy object.
  */
@@ -1048,7 +772,7 @@ function wp_save_nav_menu_items( $menu_id = 0, $menu_data = array() ) {
 	if ( 0 == $menu_id || is_nav_menu( $menu_id ) ) {
 
 		// Loop through all the menu items' POST values.
-		foreach( (array) $menu_data as $_possible_db_id => $_item_object_data ) {
+		foreach ( (array) $menu_data as $_possible_db_id => $_item_object_data ) {
 			if (
 				// Checkbox is not checked.
 				empty( $_item_object_data['menu-item-object-id'] ) &&
@@ -1162,7 +886,7 @@ function wp_get_nav_menu_to_edit( $menu_id = 0 ) {
 		$result .= '<p>' . __( 'Add menu items from the column on the left.' ) . '</p>';
 		$result .= '</div>';
 
-		if( empty($menu_items) )
+		if ( empty($menu_items) )
 			return $result . ' <ul class="menu" id="menu-to-edit"> </ul>';
 
 		/**
@@ -1175,13 +899,19 @@ function wp_get_nav_menu_to_edit( $menu_id = 0 ) {
 		 */
 		$walker_class_name = apply_filters( 'wp_edit_nav_menu_walker', 'Walker_Nav_Menu_Edit', $menu_id );
 
-		if ( class_exists( $walker_class_name ) )
+		if ( class_exists( $walker_class_name ) ) {
 			$walker = new $walker_class_name;
-		else
-			return new WP_Error( 'menu_walker_not_exist', sprintf( __('The Walker class named <strong>%s</strong> does not exist.'), $walker_class_name ) );
+		} else {
+			return new WP_Error( 'menu_walker_not_exist',
+				/* translators: %s: walker class name */
+				sprintf( __( 'The Walker class named %s does not exist.' ),
+					'<strong>' . $walker_class_name . '</strong>'
+				)
+			);
+		}
 
 		$some_pending_menu_items = $some_invalid_menu_items = false;
-		foreach( (array) $menu_items as $menu_item ) {
+		foreach ( (array) $menu_items as $menu_item ) {
 			if ( isset( $menu_item->post_status ) && 'draft' == $menu_item->post_status )
 				$some_pending_menu_items = true;
 			if ( ! empty( $menu_item->_invalid ) )
@@ -1215,6 +945,7 @@ function wp_nav_menu_manage_columns() {
 	return array(
 		'_title' => __('Show advanced menu properties'),
 		'cb' => '<input type="checkbox" />',
+		'title-attribute' => __('Title Attribute'),
 		'link-target' => __('Link Target'),
 		'css-classes' => __('CSS Classes'),
 		'xfn' => __('Link Relationship (XFN)'),
@@ -1228,6 +959,7 @@ function wp_nav_menu_manage_columns() {
  * @access private
  * @since 3.0.0
  *
+ * @global wpdb $wpdb WordPress database abstraction object.
  */
 function _wp_delete_orphaned_draft_menu_items() {
 	global $wpdb;
@@ -1236,10 +968,9 @@ function _wp_delete_orphaned_draft_menu_items() {
 	// Delete orphaned draft menu items.
 	$menu_items_to_delete = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts AS p LEFT JOIN $wpdb->postmeta AS m ON p.ID = m.post_id WHERE post_type = 'nav_menu_item' AND post_status = 'draft' AND meta_key = '_menu_item_orphaned' AND meta_value < '%d'", $delete_timestamp ) );
 
-	foreach( (array) $menu_items_to_delete as $menu_item_id )
+	foreach ( (array) $menu_items_to_delete as $menu_item_id )
 		wp_delete_post( $menu_item_id, true );
 }
-add_action('admin_head-nav-menus.php', '_wp_delete_orphaned_draft_menu_items');
 
 /**
  * Saves nav menu items
@@ -1252,7 +983,7 @@ add_action('admin_head-nav-menus.php', '_wp_delete_orphaned_draft_menu_items');
  */
 function wp_nav_menu_update_menu_items ( $nav_menu_selected_id, $nav_menu_selected_title ) {
 	$unsorted_menu_items = wp_get_nav_menu_items( $nav_menu_selected_id, array( 'orderby' => 'ID', 'output' => ARRAY_A, 'output_key' => 'ID', 'post_status' => 'draft,publish' ) );
-
+	$messages = array();
 	$menu_items = array();
 	// Index menu items by db ID
 	foreach ( $unsorted_menu_items as $_item )
@@ -1268,7 +999,7 @@ function wp_nav_menu_update_menu_items ( $nav_menu_selected_id, $nav_menu_select
 	wp_defer_term_counting( true );
 	// Loop through all the menu items' POST variables
 	if ( ! empty( $_POST['menu-item-db-id'] ) ) {
-		foreach( (array) $_POST['menu-item-db-id'] as $_key => $k ) {
+		foreach ( (array) $_POST['menu-item-db-id'] as $_key => $k ) {
 
 			// Menu item title can't be blank
 			if ( ! isset( $_POST['menu-item-title'][ $_key ] ) || '' == $_POST['menu-item-title'][ $_key ] )
@@ -1280,10 +1011,11 @@ function wp_nav_menu_update_menu_items ( $nav_menu_selected_id, $nav_menu_select
 
 			$menu_item_db_id = wp_update_nav_menu_item( $nav_menu_selected_id, ( $_POST['menu-item-db-id'][$_key] != $_key ? 0 : $_key ), $args );
 
-			if ( is_wp_error( $menu_item_db_id ) )
+			if ( is_wp_error( $menu_item_db_id ) ) {
 				$messages[] = '<div id="message" class="error"><p>' . $menu_item_db_id->get_error_message() . '</p></div>';
-			elseif ( isset( $menu_items[$menu_item_db_id] ) )
-				unset( $menu_items[$menu_item_db_id] );
+			} else {
+				unset( $menu_items[ $menu_item_db_id ] );
+			}
 		}
 	}
 
@@ -1317,7 +1049,12 @@ function wp_nav_menu_update_menu_items ( $nav_menu_selected_id, $nav_menu_select
 	/** This action is documented in wp-includes/nav-menu.php */
 	do_action( 'wp_update_nav_menu', $nav_menu_selected_id );
 
-	$messages[] = '<div id="message" class="updated"><p>' . sprintf( __( '<strong>%1$s</strong> has been updated.' ), $nav_menu_selected_title ) . '</p></div>';
+	$messages[] = '<div id="message" class="updated notice is-dismissible"><p>' .
+		/* translators: %s: nav menu title */
+		sprintf( __( '%s has been updated.' ),
+			'<strong>' . $nav_menu_selected_title . '</strong>'
+		) . '</p></div>';
+
 	unset( $menu_items, $unsorted_menu_items );
 
 	return $messages;
