@@ -10,18 +10,21 @@
 /** Load WordPress Administration Bootstrap */
 require_once( dirname( __FILE__ ) . '/admin.php' );
 
+/** WordPress Translation Install API */
+require_once( ABSPATH . 'wp-admin/includes/translation-install.php' );
+
 if ( ! is_multisite() )
 	wp_die( __( 'Multisite support is not enabled.' ) );
 
 if ( ! current_user_can( 'manage_sites' ) )
 	wp_die( __( 'You do not have sufficient permissions to add sites to this network.' ) );
 
-	get_current_screen()->add_help_tab( array(
-		'id'      => 'overview',
-		'title'   => __('Overview'),
-		'content' =>
-			'<p>' . __('This screen is for Super Admins to add new sites to the network. This is not affected by the registration settings.') . '</p>' .
-			'<p>' . __('If the admin email for the new site does not exist in the database, a new user will also be created.') . '</p>'
+get_current_screen()->add_help_tab( array(
+	'id'      => 'overview',
+	'title'   => __('Overview'),
+	'content' =>
+		'<p>' . __('This screen is for Super Admins to add new sites to the network. This is not affected by the registration settings.') . '</p>' .
+		'<p>' . __('If the admin email for the new site does not exist in the database, a new user will also be created.') . '</p>'
 ) );
 
 get_current_screen()->set_help_sidebar(
@@ -43,14 +46,27 @@ if ( isset($_REQUEST['action']) && 'add-site' == $_REQUEST['action'] ) {
 
 	// If not a subdomain install, make sure the domain isn't a reserved word
 	if ( ! is_subdomain_install() ) {
-		/** This filter is documented in wp-includes/ms-functions.php */
-		$subdirectory_reserved_names = apply_filters( 'subdirectory_reserved_names', array( 'page', 'comments', 'blog', 'files', 'feed' ) );
-		if ( in_array( $domain, $subdirectory_reserved_names ) )
-			wp_die( sprintf( __('The following words are reserved for use by WordPress functions and cannot be used as blog names: <code>%s</code>' ), implode( '</code>, <code>', $subdirectory_reserved_names ) ) );
+		$subdirectory_reserved_names = get_subdirectory_reserved_names();
+
+		if ( in_array( $domain, $subdirectory_reserved_names ) ) {
+			wp_die( sprintf( __( 'The following words are reserved for use by WordPress functions and cannot be used as blog names: <code>%s</code>' ), implode( '</code>, <code>', $subdirectory_reserved_names ) ) );
+		}
 	}
 
 	$title = $blog['title'];
 
+	$meta = array(
+		'public' => 1
+	);
+
+	// Handle translation install for the new site.
+	if ( ! empty( $_POST['WPLANG'] ) && wp_can_install_language_pack() ) {
+		$language = wp_download_language_pack( wp_unslash( $_POST['WPLANG'] ) );
+		if ( $language ) {
+			$meta['WPLANG'] = $language;
+		}
+	}
+
 	if ( empty( $domain ) )
 		wp_die( __( 'Missing or invalid site address.' ) );
 
@@ -74,16 +90,28 @@ if ( isset($_REQUEST['action']) && 'add-site' == $_REQUEST['action'] ) {
 	$password = 'N/A';
 	$user_id = email_exists($email);
 	if ( !$user_id ) { // Create a new user with a random password
+		$user_id = username_exists( $domain );
+		if ( $user_id ) {
+			wp_die( __( 'The domain or path entered conflicts with an existing username.' ) );
+		}
 		$password = wp_generate_password( 12, false );
 		$user_id = wpmu_create_user( $domain, $password, $email );
-		if ( false === $user_id )
+		if ( false === $user_id ) {
 			wp_die( __( 'There was an error creating the user.' ) );
-		else
-			wp_new_user_notification( $user_id, 'both' );
+		}
+
+		/**
+		  * Fires after a new user has been created via the network site-new.php page.
+		  *
+		  * @since 4.4.0
+		  *
+		  * @param int $user_id ID of the newly created user.
+		  */
+		do_action( 'network_site_new_created_user', $user_id );
 	}
 
 	$wpdb->hide_errors();
-	$id = wpmu_create_blog( $newdomain, $path, $title, $user_id , array( 'public' => 1 ), $current_site->id );
+	$id = wpmu_create_blog( $newdomain, $path, $title, $user_id, $meta, $current_site->id );
 	$wpdb->show_errors();
 	if ( ! is_wp_error( $id ) ) {
 		if ( ! is_super_admin( $user_id ) && !get_user_option( 'primary_blog', $user_id ) ) {
@@ -155,6 +183,35 @@ if ( ! empty( $messages ) ) {
 			<th scope="row"><label for="site-title"><?php _e( 'Site Title' ) ?></label></th>
 			<td><input name="blog[title]" type="text" class="regular-text" id="site-title" /></td>
 		</tr>
+		<?php
+		$languages    = get_available_languages();
+		$translations = wp_get_available_translations();
+		if ( ! empty( $languages ) || ! empty( $translations ) ) :
+			?>
+			<tr class="form-field form-required">
+				<th scope="row"><label for="site-language"><?php _e( 'Site Language' ); ?></label></th>
+				<td>
+					<?php
+					// Network default.
+					$lang = get_site_option( 'WPLANG' );
+
+					// Use English if the default isn't available.
+					if ( ! in_array( $lang, $languages ) ) {
+						$lang = '';
+					}
+
+					wp_dropdown_languages( array(
+						'name'                        => 'WPLANG',
+						'id'                          => 'site-language',
+						'selected'                    => $lang,
+						'languages'                   => $languages,
+						'translations'                => $translations,
+						'show_available_translations' => wp_can_install_language_pack(),
+					) );
+					?>
+				</td>
+			</tr>
+		<?php endif; // Languages. ?>
 		<tr class="form-field form-required">
 			<th scope="row"><label for="admin-email"><?php _e( 'Admin Email' ) ?></label></th>
 			<td><input name="blog[email]" type="email" class="regular-text wp-suggest-user" id="admin-email" data-autocomplete-type="search" data-autocomplete-field="user_email" /></td>
