@@ -1,14 +1,12 @@
 <?php
 /**
- * Simple and uniform HTTP request API.
+ * Core HTTP Request API
  *
- * Will eventually replace and standardize the WordPress HTTP requests made.
- *
- * @link https://core.trac.wordpress.org/ticket/4779 HTTP API Proposal
+ * Standardizes the HTTP requests for WordPress. Handles cookies, gzip encoding and decoding, chunk
+ * decoding, if HTTP 1.1 and various other difficult HTTP protocol implementations.
  *
  * @package WordPress
  * @subpackage HTTP
- * @since 2.7.0
  */
 
 /**
@@ -17,14 +15,16 @@
  * @since 2.7.0
  * @access private
  *
+ * @staticvar WP_Http $http
+ *
  * @return WP_Http HTTP Transport object.
  */
 function _wp_http_get_object() {
-	static $http;
+	static $http = null;
 
-	if ( is_null($http) )
+	if ( is_null( $http ) ) {
 		$http = new WP_Http();
-
+	}
 	return $http;
 }
 
@@ -149,8 +149,8 @@ function wp_safe_remote_head( $url, $args = array() ) {
  * @return WP_Error|array The response or WP_Error on failure.
  */
 function wp_remote_request($url, $args = array()) {
-	$objFetchSite = _wp_http_get_object();
-	return $objFetchSite->request($url, $args);
+	$http = _wp_http_get_object();
+	return $http->request( $url, $args );
 }
 
 /**
@@ -166,8 +166,8 @@ function wp_remote_request($url, $args = array()) {
  * @return WP_Error|array The response or WP_Error on failure.
  */
 function wp_remote_get($url, $args = array()) {
-	$objFetchSite = _wp_http_get_object();
-	return $objFetchSite->get($url, $args);
+	$http = _wp_http_get_object();
+	return $http->get( $url, $args );
 }
 
 /**
@@ -183,8 +183,8 @@ function wp_remote_get($url, $args = array()) {
  * @return WP_Error|array The response or WP_Error on failure.
  */
 function wp_remote_post($url, $args = array()) {
-	$objFetchSite = _wp_http_get_object();
-	return $objFetchSite->post($url, $args);
+	$http = _wp_http_get_object();
+	return $http->post( $url, $args );
 }
 
 /**
@@ -200,8 +200,8 @@ function wp_remote_post($url, $args = array()) {
  * @return WP_Error|array The response or WP_Error on failure.
  */
 function wp_remote_head($url, $args = array()) {
-	$objFetchSite = _wp_http_get_object();
-	return $objFetchSite->head($url, $args);
+	$http = _wp_http_get_object();
+	return $http->head( $url, $args );
 }
 
 /**
@@ -224,7 +224,7 @@ function wp_remote_retrieve_headers( $response ) {
  *
  * @since 2.7.0
  *
- * @param array $response
+ * @param array  $response
  * @param string $header Header name to retrieve value from.
  * @return string The header value. Empty string on if incorrect parameter given, or if the header doesn't exist.
  */
@@ -287,18 +287,79 @@ function wp_remote_retrieve_body( $response ) {
 	return $response['body'];
 }
 
+/**
+ * Retrieve only the body from the raw response.
+ *
+ * @since 4.4.0
+ *
+ * @param array $response HTTP response.
+ * @return array An array of `WP_Http_Cookie` objects from the response. Empty array if there are none, or the response is a WP_Error.
+ */
+function wp_remote_retrieve_cookies( $response ) {
+	if ( is_wp_error( $response ) || empty( $response['cookies'] ) ) {
+		return array();
+	}
+
+	return $response['cookies'];
+}
+
+/**
+ * Retrieve a single cookie by name from the raw response.
+ *
+ * @since 4.4.0
+ *
+ * @param array  $response HTTP response.
+ * @param string $name     The name of the cookie to retrieve.
+ * @return WP_Http_Cookie|string The `WP_Http_Cookie` object. Empty string if the cookie isn't present in the response.
+ */
+function wp_remote_retrieve_cookie( $response, $name ) {
+	$cookies = wp_remote_retrieve_cookies( $response );
+
+	if ( empty( $cookies ) ) {
+		return '';
+	}
+
+	foreach ( $cookies as $cookie ) {
+		if ( $cookie->name === $name ) {
+			return $cookie;
+		}
+	}
+
+	return '';
+}
+
+/**
+ * Retrieve a single cookie's value by name from the raw response.
+ *
+ * @since 4.4.0
+ *
+ * @param array  $response HTTP response.
+ * @param string $name     The name of the cookie to retrieve.
+ * @return string The value of the cookie. Empty string if the cookie isn't present in the response.
+ */
+function wp_remote_retrieve_cookie_value( $response, $name ) {
+	$cookie = wp_remote_retrieve_cookie( $response, $name );
+
+	if ( ! is_a( $cookie, 'WP_Http_Cookie' ) ) {
+		return '';
+	}
+
+	return $cookie->value;
+}
+
 /**
  * Determines if there is an HTTP Transport that can process this request.
  *
  * @since 3.2.0
  *
  * @param array  $capabilities Array of capabilities to test or a wp_remote_request() $args array.
- * @param string $url Optional. If given, will check if the URL requires SSL and adds that requirement to the capabilities array.
+ * @param string $url          Optional. If given, will check if the URL requires SSL and adds
+ *                             that requirement to the capabilities array.
  *
  * @return bool
  */
 function wp_http_supports( $capabilities = array(), $url = null ) {
-	$objFetchSite = _wp_http_get_object();
+	$http = _wp_http_get_object();
 
 	$capabilities = wp_parse_args( $capabilities );
 
@@ -316,7 +377,7 @@ function wp_http_supports( $capabilities = array(), $url = null ) {
 		}
 	}
 
-	return (bool) $objFetchSite->_get_first_available_transport( $capabilities );
+	return (bool) $http->_get_first_available_transport( $capabilities );
 }
 
 /**
@@ -382,7 +443,7 @@ function get_allowed_http_origins() {
  * @since 3.4.0
  *
  * @param null|string $origin Origin URL. If not provided, the value of get_http_origin() is used.
- * @return bool|null True if the origin is allowed. False otherwise.
+ * @return string True if the origin is allowed. False otherwise.
  */
 function is_allowed_http_origin( $origin = null ) {
 	$origin_arg = $origin;
@@ -398,8 +459,8 @@ function is_allowed_http_origin( $origin = null ) {
 	 *
 	 * @since 3.4.0
 	 *
-	 * @param string $origin Result of check for allowed origin.
-	 * @param string $origin_arg original origin string passed into is_allowed_http_origin function.
+	 * @param string $origin     Result of check for allowed origin.
+	 * @param string $origin_arg Original origin string passed into is_allowed_http_origin function.
 	 */
 	return apply_filters( 'allowed_http_origin', $origin, $origin_arg );
 }
@@ -414,8 +475,8 @@ function is_allowed_http_origin( $origin = null ) {
  *
  * @since 3.4.0
  *
- * @return bool|string Returns the origin URL if headers are sent. Returns false
- * if headers are not sent.
+ * @return string|false Returns the origin URL if headers are sent. Returns false
+ *                      if headers are not sent.
  */
 function send_origin_headers() {
 	$origin = get_http_origin();
@@ -466,13 +527,12 @@ function wp_http_validate_url( $url ) {
 
 	if ( ! $same_host ) {
 		$host = trim( $parsed_url['host'], '.' );
-		if ( preg_match( '#^(([1-9]?\d|1\d\d|25[0-5]|2[0-4]\d)\.){3}([1-9]?\d|1\d\d|25[0-5]|2[0-4]\d)$#', $host ) ) {
+		if ( preg_match( '#^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$#', $host ) ) {
 			$ip = $host;
 		} else {
 			$ip = gethostbyname( $host );
-			if ( $ip === $host ) { // Error condition for gethostbyname()
-				return false;
-			}
+			if ( $ip === $host ) // Error condition for gethostbyname()
+				$ip = false;
 		}
 		if ( $ip ) {
 			$parts = array_map( 'intval', explode( '.', $ip ) );
@@ -488,9 +548,9 @@ function wp_http_validate_url( $url ) {
 				 *
 				 * @since 3.6.0
 				 *
-				 * @param bool false Whether HTTP request is external or not.
+				 * @param bool   false Whether HTTP request is external or not.
 				 * @param string $host IP of the requested host.
-				 * @param string $url URL of the requested host.
+				 * @param string $url  URL of the requested host.
 				 */
 				if ( ! apply_filters( 'http_request_host_is_external', false, $host, $url ) )
 					return false;
@@ -518,7 +578,7 @@ function wp_http_validate_url( $url ) {
  *
  * @since 3.6.0
  *
- * @param bool $is_external
+ * @param bool   $is_external
  * @param string $host
  * @return bool
  */
@@ -535,7 +595,10 @@ function allowed_http_request_hosts( $is_external, $host ) {
  *
  * @since 3.6.0
  *
- * @param bool $is_external
+ * @global wpdb $wpdb WordPress database abstraction object.
+ * @staticvar array $queried
+ *
+ * @param bool   $is_external
  * @param string $host
  * @return bool
  */
@@ -551,3 +614,49 @@ function ms_allowed_http_request_hosts( $is_external, $host ) {
 	$queried[ $host ] = (bool) $wpdb->get_var( $wpdb->prepare( "SELECT domain FROM $wpdb->blogs WHERE domain = %s LIMIT 1", $host ) );
 	return $queried[ $host ];
 }
+
+/**
+ * A wrapper for PHP's parse_url() function that handles edgecases in < PHP 5.4.7
+ *
+ * PHP 5.4.7 expanded parse_url()'s ability to handle non-absolute url's, including
+ * schemeless and relative url's with :// in the path, this works around those
+ * limitations providing a standard output on PHP 5.2~5.4+.
+ *
+ * Error suppression is used as prior to PHP 5.3.3, an E_WARNING would be generated
+ * when URL parsing failed.
+ *
+ * @since 4.4.0
+ *
+ * @param string $url The URL to parse.
+ * @return bool|array False on failure; Array of URL components on success;
+ *                    See parse_url()'s return values.
+ */
+function wp_parse_url( $url ) {
+	$parts = @parse_url( $url );
+	if ( ! $parts ) {
+		// < PHP 5.4.7 compat, trouble with relative paths including a scheme break in the path
+		if ( '/' == $url[0] && false !== strpos( $url, '://' ) ) {
+			// Since we know it's a relative path, prefix with a scheme/host placeholder and try again
+			if ( ! $parts = @parse_url( 'placeholder://placeholder' . $url ) ) {
+				return $parts;
+			}
+			// Remove the placeholder values
+			unset( $parts['scheme'], $parts['host'] );
+		} else {
+			return $parts;
+		}
+	}
+
+	// < PHP 5.4.7 compat, doesn't detect schemeless URL's host field
+	if ( '//' == substr( $url, 0, 2 ) && ! isset( $parts['host'] ) ) {
+		$path_parts = explode( '/', substr( $parts['path'], 2 ), 2 );
+		$parts['host'] = $path_parts[0];
+		if ( isset( $path_parts[1] ) ) {
+			$parts['path'] = '/' . $path_parts[1];
+		} else {
+			unset( $parts['path'] );
+		}
+	}
+
+	return $parts;
+}
